@@ -1,13 +1,12 @@
-# $Id: Message.pm 768 2005-09-05 02:25:24Z claco $
+# $Id: Message.pm 1915 2007-06-24 15:35:46Z claco $
 package Handel::Checkout::Message;
 use strict;
 use warnings;
-use vars '$AUTOLOAD';
 use overload '""' => \&stringify, fallback => 1;
 
 sub new {
     my ($class, %args) = @_;
-    my $self = bless \%args, ref $class || $class;
+    my $self = bless \%args, $class;
 
     return $self;
 };
@@ -15,13 +14,17 @@ sub new {
 sub stringify {
     my $self = shift;
 
-    return $self->text || $self;
+    if (my $text = $self->text) {
+        return $text;
+    } else {
+        return ref $self;
+    };
 };
 
 sub AUTOLOAD {
     my $self = shift;
 
-    my $name = $AUTOLOAD;
+    my $name = our $AUTOLOAD;
     $name =~ s/.*://;
 
     if (@_) {
@@ -41,14 +44,14 @@ Handel::Checkout::Message - Checkout Pipeline Process Message
 =head1 SYNOPSIS
 
     use Handel::Checkout::Message;
-
+    
     my $message = Handel::Checkout::Message->new(
         text => 'My Message',
         otherproperty => 'some data'
     );
-
+    
     $message->tempdata('stuff');
-
+    
     print $message->text;
     print $message->otherproperty;
     print $message->tempdata;
@@ -59,17 +62,31 @@ Handel::Checkout::Message is just a simple blessed hash to hold any and every
 property you throw at it. It is autoloaded, so any instance method simple loads
 or sets the corresponding key value in the hash.
 
-Handel::Checkout::Message stringifies to text() if available, otherwise it returns $self.
+Handel::Checkout::Message stringifies to text() if available, otherwise it
+returns $self.
 
 =head1 CONSTRUCTOR
 
-=head2 new([%options])
+=head2 new
+
+=over
+
+=item Arguments: %options
+
+=back
 
     my $message = Handel::Checkout::Message->new(
         text => 'My Message',
         otherproperty => 'some data'
     );
 
+=head1 METHODS
+
+=head2 stringify
+
+Returns C<text> in scalar context. If no text is set, it returns the name of the
+current message object.
+
 =head1 SEE ALSO
 
 L<Handel::Constants>, L<Handel::Checkout::Plugin>, L<Handel::Order>
