@@ -1,26 +1,31 @@
-# $Id: AssignOrderNumber.pm 797 2005-09-12 02:22:07Z claco $
+# $Id: AssignOrderNumber.pm 1915 2007-06-24 15:35:46Z claco $
 package Handel::Checkout::Plugin::AssignOrderNumber;
 use strict;
 use warnings;
-use base 'Handel::Checkout::Plugin';
-use Handel::Constants qw(:checkout);
+
+BEGIN {
+    use base qw/Handel::Checkout::Plugin/;
+    use Handel::Constants qw/:checkout/;
+};
 
 sub register {
     my ($self, $ctx) = @_;
 
     $ctx->add_handler(CHECKOUT_PHASE_FINALIZE, \&handler);
+
+    return;
 };
 
 sub handler {
     my ($self, $ctx) = @_;
 
     $ctx->order->number(time);
-    $ctx->order->updated(scalar localtime);
 
     return CHECKOUT_HANDLER_OK;
 };
 
 1;
+__END__
 
 =head1 NAME
 
@@ -29,13 +34,13 @@ Handel::Checkout::Plugin::AssignOrderNumber - Checkout plugin to assign order nu
 =head1 SYNOPSIS
 
     use Handel::Checkout;
-
+    
     my $checkout = Handel::Checkout->new({
         order       => $order,
         phases      => 'CHECKOUT_PHASE_FINALIZE',
         loadplugins => 'Handel::Checkout::Plugin::AssignOrderNumber'
     });
-
+    
     $checkout->process;
 
 =head1 DESCRIPTION
@@ -43,6 +48,16 @@ Handel::Checkout::Plugin::AssignOrderNumber - Checkout plugin to assign order nu
 This checkout plugin simply assigns a number to $order->number during the
 CHECKOUT_PHASE_FINALIZE phase.
 
+=head1 METHODS
+
+=head2 register
+
+Registers this plugin for the CHECKOUT_PHASE_FINALIZE phase.
+
+=head2 handler
+
+Assigns a number to the current order.
+
 =head1 SEE ALSO
 
 L<Handel::Checkout::Plugin>, L<Handel::Checkout>
