@@ -1,25 +1,31 @@
-# $Id: MarkOrderSaved.pm 797 2005-09-12 02:22:07Z claco $
+# $Id: MarkOrderSaved.pm 1915 2007-06-24 15:35:46Z claco $
 package Handel::Checkout::Plugin::MarkOrderSaved;
 use strict;
 use warnings;
-use base 'Handel::Checkout::Plugin';
-use Handel::Constants qw(:checkout :order);
+
+BEGIN {
+    use base qw/Handel::Checkout::Plugin/;
+    use Handel::Constants qw/:checkout :order/;
+};
 
 sub register {
     my ($self, $ctx) = @_;
 
     $ctx->add_handler(CHECKOUT_PHASE_FINALIZE, \&handler);
+
+    return;
 };
 
 sub handler {
     my ($self, $ctx) = @_;
 
-    $ctx->order->type(ORDER_TYPE_SAVED);
+    $ctx->order->save;
 
     return CHECKOUT_HANDLER_OK;
 };
 
 1;
+__END__
 
 =head1 NAME
 
@@ -28,13 +34,13 @@ Handel::Checkout::Plugin::MarkOrderSaved - Checkout plugin to mark the order ORD
 =head1 SYNOPSIS
 
     use Handel::Checkout;
-
+    
     my $checkout = Handel::Checkout->new({
         order       => $order,
         phases      => 'CHECKOUT_PHASE_FINALIZE',
         loadplugins => 'Handel::Checkout::Plugin::MarkOrderSaved'
     });
-
+    
     $checkout->process;
 
 =head1 DESCRIPTION
@@ -42,6 +48,16 @@ Handel::Checkout::Plugin::MarkOrderSaved - Checkout plugin to mark the order ORD
 This checkout plugin simply changes $order->type to ORDER_TYPE_SAVED during the
 CHECKOUT_PHASE_FINALIZE phase.
 
+=head1 METHODS
+
+=head2 register
+
+Registers this plugin for the CHECKOUT_PHASE_FINALIZE phase.
+
+=head2 handler
+
+Calls L<Handel::Order/save> to mark the current order as saved.
+
 =head1 SEE ALSO
 
 L<Handel::Checkout::Plugin>, L<Handel::Checkout>
