@@ -1,14 +1,16 @@
-# $Id: Exception.pm 1100 2006-02-01 01:15:34Z claco $
+# $Id: Exception.pm 1915 2007-06-24 15:35:46Z claco $
 package Handel::Exception;
 use strict;
 use warnings;
 
 BEGIN {
-    use base 'Error';
-    use Handel::L10N qw(translate);
-    eval 'require Apache::AxKit::Exception';
-    if (!$@) {
-        push @__PACKAGE__::ISA, 'Apache::AxKit::Exception';
+    use base qw/Error/;
+    use Handel::L10N qw/translate/;
+    use Class::Inspector;
+
+    if (Class::Inspector->loaded('Apache::AxKit::Exception')) {
+        no strict 'vars';
+        push @ISA, 'Apache::AxKit::Exception'; ## no critic
     };
 };
 
@@ -18,13 +20,11 @@ sub new {
     my $class = shift;
     my %args  = @_;
     my $text  = translate(
-        $args{-text} || 'An unspecified error has occurred'
+        $args{-text} || 'UNHANDLED_EXCEPTION'
     );
 
-    if ( defined( $args{-details} ) ) {
+    if ( defined($args{'-details'}) && ! ref $args{'-details'}) {
         $text .= ': ' . $args{-details};
-    } else {
-        # $text .= '.';
     };
 
     ## don't pass the original text
@@ -33,34 +33,40 @@ sub new {
     return $class->SUPER::new( -text => $text, %args );
 };
 
+sub details {
+    return shift->{'-details'};
+};
+
+sub results {
+    return shift->{'-results'};
+};
 
 package Handel::Exception::Constraint;
 use strict;
 use warnings;
 
 BEGIN {
-    use base 'Handel::Exception';
+    use base qw/Handel::Exception/;
 };
 
 sub new {
     my $class = shift;
     return $class->SUPER::new(
-        -text => 'The supplied field(s) failed database constraints', @_ );
+        -text => 'CONSTRAINT_EXCEPTION', @_ );
 };
 
-
 package Handel::Exception::Argument;
 use strict;
 use warnings;
 
 BEGIN {
-    use base 'Handel::Exception';
+    use base qw/Handel::Exception/;
 };
 
 sub new {
     my $class = shift;
     return $class->SUPER::new(
-        -text => 'The argument supplied is invalid or of the wrong type', @_ );
+        -text => 'ARGUMENT_EXCEPTION', @_ );
 };
 
 package Handel::Exception::Taglib;
@@ -68,13 +74,13 @@ use strict;
 use warnings;
 
 BEGIN {
-    use base 'Handel::Exception';
+    use base qw/Handel::Exception/;
 };
 
 sub new {
     my $class = shift;
     return $class->SUPER::new(
-        -text => 'The tag is out of scope or missing required child tags', @_ );
+        -text => 'XSP_TAG_EXCEPTION', @_ );
 };
 
 package Handel::Exception::Order;
@@ -82,13 +88,13 @@ use strict;
 use warnings;
 
 BEGIN {
-    use base 'Handel::Exception';
+    use base qw/Handel::Exception/;
 };
 
 sub new {
     my $class = shift;
     return $class->SUPER::new(
-        -text => 'An error occurred while while creating or validating the current order', @_ );
+        -text => 'ORDER_EXCEPTION', @_ );
 };
 
 package Handel::Exception::Checkout;
@@ -96,13 +102,55 @@ use strict;
 use warnings;
 
 BEGIN {
-    use base 'Handel::Exception';
+    use base qw/Handel::Exception/;
 };
 
 sub new {
     my $class = shift;
     return $class->SUPER::new(
-        -text => 'An error occurred during the checkout process', @_ );
+        -text => 'CHECKOUT_EXCEPTION', @_ );
+};
+
+package Handel::Exception::Storage;
+use strict;
+use warnings;
+
+BEGIN {
+    use base qw/Handel::Exception/;
+};
+
+sub new {
+    my $class = shift;
+    return $class->SUPER::new(
+        -text => 'STORAGE_EXCEPTION', @_ );
+};
+
+package Handel::Exception::Validation;
+use strict;
+use warnings;
+
+BEGIN {
+    use base qw/Handel::Exception/;
+};
+
+sub new {
+    my $class = shift;
+    return $class->SUPER::new(
+        -text => 'VALIDATION_EXCEPTION', @_ );
+};
+
+package Handel::Exception::Virtual;
+use strict;
+use warnings;
+
+BEGIN {
+    use base qw/Handel::Exception/;
+};
+
+sub new {
+    my $class = shift;
+    return $class->SUPER::new(
+        -text => 'VIRTUAL_METHOD', @_ );
 };
 
 1;
@@ -116,13 +164,11 @@ Handel::Exception - Exceptions used within Handel
 
     use Handel::Cart;
     use Handel::Exception' qw(:try);
-
+    
     try {
         my $cart = Handel::Cart->new('junk crap');
-
     } catch Handel::Exception::Argument with {
         print 'Passed the wrong arguments to method';
-
     } catch Handel::Exception with {
         print 'Unknown issue with Handel';
     } catch Error with {
@@ -133,8 +179,8 @@ Handel::Exception - Exceptions used within Handel
 
 =head1 DESCRIPTION
 
-C<Handel::Exception> subclasses L<Error> and attempts to throw exceptions when
-unexpected things happen.
+Handel::Exception subclasses L<Error|Error> and attempts to throw exceptions
+when unexpected things happen.
 
 =head1 EXCEPTIONS
 
@@ -161,8 +207,21 @@ exceptions.
 =head2 Handel::Exception::Constraint
 
 This exception is thrown if a database constraint is violated. This is true for
-both raw DBI database constraint errors as well as  field updates that don't
-pass constraints in C<Handel::Constraints>.
+both raw DBI database constraint errors as well as field updates that don't
+pass constraints in
+L<Handel::Components::Constraints|Handel::Components::Constraints>.
+
+=head2 Handel::Exception::Validation
+
+This exception is thrown if the validation performed by
+L<Handel::Components::Validation|Handel::Components::Validation> has failed.
+If the validation component returned a result object, that can be found in
+$E-E<gt>results.
+
+=head2 Handel::Exception::Storage
+
+This exception is thrown if there are any configuration or setup errors in
+Handel::Storage.
 
 =head2 Handel::Exception::Argument
 
@@ -172,22 +231,31 @@ into methods.
 =head2 Handel::Exception::Taglib
 
 This exception is thrown when an unexpected error occurs within
-C<AxKit::XSP::Handel::Cart> taglib.
+the AxKit taglibs.
 
 =head1 METHODS
 
 =head2 new
 
-This returns a new C<Handel::Exception> object. This is mostly used internally
-by L<Error>. In most circumstance, you don't need to call C<new> at all.
+This returns a new Handel::Exception object. This is mostly used internally
+by L<Error|Error>. In most circumstances, you don't need to call C<new> at all.
 Instead, simply use the C<throw> syntax:
 
     use Handel::Exceptions;
-
+    
     throw Handel::Exception::Taglib(
         -text => translate("Tag '[_1]' not valid inside of other Handel tags", $tag)
     ) if ($context[$#context] ne 'root');
 
+=head2 details
+
+Returns the details portion of the exception message if there are any.
+
+=head2 results
+
+Returns the data validation result errors from exceptions thrown by
+L<Handel::Components::Validation|Handel::Components::Validation>.
+
 =head1 SEE ALSO
 
 L<Error>, L<Handel::Constraints>
