@@ -1,8 +1,8 @@
-# $Id: Checkout.pm 1043 2005-12-24 03:40:20Z claco $
+# $Id: Checkout.pm 1915 2007-06-24 15:35:46Z claco $
 package Handel::Subclassing::Checkout;
 use strict;
 use warnings;
-use base 'Handel::Checkout';
+use base qw/Handel::Checkout/;
 
 __PACKAGE__->order_class('Handel::Subclassing::Order');
 
