@@ -1,9 +1,10 @@
-# $Id: OrderCart.pm 1050 2006-01-05 01:34:35Z claco $
+# $Id: OrderCart.pm 1915 2007-06-24 15:35:46Z claco $
 package Handel::Subclassing::OrderCart;
 use strict;
 use warnings;
-use base 'Handel::Order';
+use base qw/Handel::Order/;
 
 __PACKAGE__->cart_class('Handel::Subclassing::OrdersCart');
+__PACKAGE__->create_accessors;
 
 1;
