@@ -1,9 +1,9 @@
-# $Id: ValidateError.pm 837 2005-09-19 22:56:39Z claco $
+# $Id: ValidateError.pm 1915 2007-06-24 15:35:46Z claco $
 package Handel::TestPipeline::ValidateError;
 use strict;
 use warnings;
 use base 'Handel::Checkout::Plugin';
-use Handel::Constants qw(:checkout :returnas);
+use Handel::Constants qw(:checkout);
 
 sub register {
     my ($self, $ctx) = @_;
@@ -19,8 +19,8 @@ sub handler {
         my $subtotal = 0;
 
         eval {
-            my $items = $order->items(undef, RETURNAS_ITERATOR);
-            while (my $item = $items->next) {
+            my @items = $order->items;
+            foreach my $item (@items) {
                 $item->sku('ERRORSKU');
             };
             $order->billtofirstname('ErrorBillToFirstName');
@@ -42,4 +42,4 @@ sub handler {
     };
 };
 
-1;
\ No newline at end of file
+1;
