@@ -1,9 +1,9 @@
-# $Id: WriteToStash.pm 837 2005-09-19 22:56:39Z claco $
+# $Id: WriteToStash.pm 1915 2007-06-24 15:35:46Z claco $
 package Handel::TestPipeline::WriteToStash;
 use strict;
 use warnings;
 use base 'Handel::Checkout::Plugin';
-use Handel::Constants qw(:checkout :returnas);
+use Handel::Constants qw(:checkout);
 
 sub register {
     my ($self, $ctx) = @_;
@@ -19,4 +19,4 @@ sub handler {
     return CHECKOUT_HANDLER_OK;
 };
 
-1;
\ No newline at end of file
+1;
